==> deepin-camera_1.0.0.15.orig.tar.xz: deepin-camera-1.0.0.15/src/translations/deepin-camera_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.1">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>La gravació de vídeo està en curs. Voleu tancar la finestra?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Obre la carpeta</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paràmetres</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Cap</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Obre la carpeta</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>No teniu permís per operar en aquesta carpeta.</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation>Carpeta no vàlida</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Obre la carpeta</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paràmetres</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Bàsic</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Ubicació del fitxer</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Grava</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Mode de ràfega</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Retard del temporitzador</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Sortida</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Format de sortida</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 pcs</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 pcs</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Cap</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Càmera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>La Càmera és una utilitat de captura d’imatges i vídeos que usa la càmera o la càmera web del PC.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>El fitxer no s&apos;ha desat.</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Desa-ho a:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Fotografia:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Vídeo:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Paràmetres de la resolució</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Resolució:</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation>Fes una foto</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Gravació de vídeo</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Interromp la presa de fotos</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Cap</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>No s&apos;ha trobat cap càmera web.</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>La càmera web s&apos;usa.</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Interromp la gravació</translation>
    </message>
</context>
</TS>

==> deepin-camera_1.1.2.orig.tar.xz: deepin-camera-1.1.2/src/translations/deepin-camera_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>La gravació de vídeo està en curs. Voleu tancar la finestra?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Obre la carpeta</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paràmetres</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Cap</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Obre la carpeta</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimeix</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>No teniu permís per operar en aquesta carpeta.</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Carpeta no vàlida</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Obre la carpeta</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paràmetres</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Bàsic</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Ubicació del fitxer</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Grava</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Mode de ràfega</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Retard del temporitzador</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Sortida</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Format de sortida</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 pcs</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 pcs</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Cap</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Càmera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>La Càmera és una utilitat de captura d’imatges i vídeos que usa la càmera o la càmera web del PC.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>El fitxer no s&apos;ha desat.</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Desa-ho a:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Fotografia:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Vídeo:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Paràmetres de la resolució</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Resolució:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Fotografies:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Vídeos:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Efectes de so</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Càmera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paràmetres</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Interromp la gravació</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Obre</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimeix</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostra&apos;n les dreceres</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Interromp la presa de fotos</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Menú contextual</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation>Fes una foto</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Gravació de vídeo</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Interromp la presa de fotos</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Cap</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>No s&apos;ha trobat cap càmera web.</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>La càmera web s&apos;usa.</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Interromp la gravació</translation>
    </message>
</context>
</TS>
